function v=compute_ekman_surge_bexn(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_bexn
% Script automatically generated by fit_ekman_surge_bexn.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.040791
% RMSE  = 80.4144
% MEAN  = -44.661
% RANGE = -185.6937 - 167.8504

beta( 1 )= 8.3689e+00 ;
beta( 2 )= 4.4577e+00 ;
beta( 3 )= -1.5488e+01 ;
beta( 4 )= -2.7473e+00 ;

v=beta(1) + beta(2)*(vt.*cos(phi*pi/180)).^beta(3) + beta(4)*phi_in;
